# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Annotated, TypedDict

from ...._utils import PropertyInfo

__all__ = ["InboxCreateParams"]


class InboxCreateParams(TypedDict, total=False):
    address: str

    display_name: Annotated[str, PropertyInfo(alias="displayName")]
