# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, TypedDict

__all__ = ["PartyListParams"]


class PartyListParams(TypedDict, total=False):
    email: str

    query: str

    type: Literal["person", "organization"]
